==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
var ToolCommandEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolCommandEventArgsDescriptionMetadata, _super);
    function ToolCommandEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolCommandEventArgsDescriptionMetadata.b = function (a) {
        if (ToolCommandEventArgsDescriptionMetadata.a == null) {
            ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
        }
        if (a.k(ToolCommandEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(ToolCommandEventArgsDescriptionMetadata.a);
        ToolCommandDescriptionMetadata.d(a);
    };
    ToolCommandEventArgsDescriptionMetadata.c = function (a) {
        a.item("Command", "ExportedType:ToolCommand");
    };
    ToolCommandEventArgsDescriptionMetadata.d = function (a) {
        ToolCommandEventArgsDescriptionMetadata.b(a);
        a.ad("ToolCommandEventArgs", function () { return new ToolCommandEventArgsDescription(); });
        a.ac("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
    };
    ToolCommandEventArgsDescriptionMetadata.$t = markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
}(Base));
export { ToolCommandEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
var ToolCommandEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolCommandEventArgsDescriptionMetadata, _super);
    function ToolCommandEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolCommandEventArgsDescriptionMetadata.b = function (a) {
        if (ToolCommandEventArgsDescriptionMetadata.a == null) {
            ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
        }
        if (a.k(ToolCommandEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(ToolCommandEventArgsDescriptionMetadata.a);
        ToolCommandDescriptionMetadata.d(a);
    };
    ToolCommandEventArgsDescriptionMetadata.c = function (a) {
        a.item("Command", "ExportedType:ToolCommand");
    };
    ToolCommandEventArgsDescriptionMetadata.d = function (a) {
        ToolCommandEventArgsDescriptionMetadata.b(a);
        a.ae("ToolCommandEventArgs", function () { return new ToolCommandEventArgsDescription(); });
        a.ad("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
    };
    ToolCommandEventArgsDescriptionMetadata.$t = markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
}(Base));
export { ToolCommandEventArgsDescriptionMetadata };
